/***************************** Include Files *******************************/

#include "opb_sil00.h"

/************************** Function Definitions ***************************/

/**
 *
 * Enable all possible interrupts from OPB_SIL00 device.
 *
 * @param   baseaddr_p is the base address of the OPB_SIL00 device.
 *
 * @return  None.
 *
 * @note    None.
 *
 */
void OPB_SIL00_EnableInterrupt(void * baseaddr_p)
{
  Xuint32 baseaddr;
  baseaddr = (Xuint32) baseaddr_p;

  /*
   * Enable all interrupt source from user logic.
   */
  OPB_SIL00_mWriteReg(baseaddr, OPB_SIL00_INTR_IER_OFFSET, 0x00000001);

  /*
   * Enable all possible interrupt sources from device.
   */
  OPB_SIL00_mWriteReg(baseaddr, OPB_SIL00_INTR_DIER_OFFSET,
    INTR_TERR_MASK
    | INTR_DPTO_MASK
    | INTR_IPIR_MASK
    );

  /*
   * Set global interrupt enable.
   */
  OPB_SIL00_mWriteReg(baseaddr, OPB_SIL00_INTR_DGIER_OFFSET, INTR_GIE_MASK);
}

/**
 *
 * Example interrupt controller handler for OPB_SIL00 device.
 * This is to show example of how to toggle write back ISR to clear interrupts.
 *
 * @param   baseaddr_p is the base address of the OPB_SIL00 device.
 *
 * @return  None.
 *
 * @note    None.
 *
 */
void OPB_SIL00_Intr_DefaultHandler(void * baseaddr_p)
{
  Xuint32 baseaddr;
  Xuint32 IntrStatus;

  baseaddr = (Xuint32) baseaddr_p;

  /*
   * Get status from IP Interrupt Status Register.
   */
  IntrStatus = OPB_SIL00_mReadReg(baseaddr, OPB_SIL00_INTR_ISR_OFFSET);

//  xil_printf("IP Interrupt! Status register (ISR) value : 0x%08x \n\r", IntrStatus);

  /*
   * Clear IP interrupts by toggle write back to IP ISR register.
   */
  OPB_SIL00_mWriteReg(baseaddr, OPB_SIL00_INTR_ISR_OFFSET, IntrStatus);
}

